==> apache-streampipes-0.68.0-incubating-source-release.zip: apache-streampipes-0.68.0-incubating/streampipes-wrapper-spark/src/main/java/org/apache/streampipes/wrapper/spark/AbstractSparkDeclarer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.wrapper.spark;

import org.apache.streampipes.container.declarer.InvocableDeclarer;
import org.apache.streampipes.model.Response;
import org.apache.streampipes.model.base.InvocableStreamPipesEntity;
import org.apache.streampipes.model.base.NamedStreamPipesEntity;

public abstract class AbstractSparkDeclarer<D extends NamedStreamPipesEntity, I extends InvocableStreamPipesEntity, SR extends SparkRuntime> implements InvocableDeclarer<D, I> {
  protected SR runtime;
  protected I graph;

  @Override
  public Response invokeRuntime(I sepaInvocation) {
    runtime = getRuntime(sepaInvocation);
    graph = sepaInvocation;

    if (runtime.startExecution()) {
      return new Response(graph.getElementId(), true);
    } else {
      return new Response(graph.getElementId(), false);
    }
  }

  @Override
  public Response detachRuntime(String s) {
    if (runtime.stop()) {
      return new Response(graph.getElementId(), true);
    } else {
      return new Response(graph.getElementId(), false);
    }
  }

  protected abstract SR getRuntime(I graph);
}

==> apache-streampipes-0.69.0-incubating-source-release.zip: apache-streampipes-0.69.0-incubating/streampipes-wrapper-spark/src/main/java/org/apache/streampipes/wrapper/spark/AbstractSparkDeclarer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.wrapper.spark;

import org.apache.streampipes.container.declarer.InvocableDeclarer;
import org.apache.streampipes.model.Response;
import org.apache.streampipes.model.base.InvocableStreamPipesEntity;
import org.apache.streampipes.model.base.NamedStreamPipesEntity;

public abstract class AbstractSparkDeclarer<D extends NamedStreamPipesEntity, I extends InvocableStreamPipesEntity, SR extends SparkRuntime> implements InvocableDeclarer<D, I> {
  protected SR runtime;
  protected I graph;

  @Override
  public Response invokeRuntime(I sepaInvocation, String serviceId) {
    runtime = getRuntime(sepaInvocation);
    graph = sepaInvocation;

    if (runtime.startExecution()) {
      return new Response(graph.getElementId(), true);
    } else {
      return new Response(graph.getElementId(), false);
    }
  }

  @Override
  public Response detachRuntime(String pipelineId, String serviceId) {
    if (runtime.stop()) {
      return new Response(graph.getElementId(), true);
    } else {
      return new Response(graph.getElementId(), false);
    }
  }

  protected abstract SR getRuntime(I graph);
}
